'use client';
import { useEffect, useState, useId } from 'react';
import { animated, useInView, useSpring } from '@react-spring/web';

function DesktopPopup({letter, message}: {letter: string, message: string}){
	const [avatarSprings, avatarApi] = useSpring(()=>({ from: { scale: 0, rotate: 0 }, config: { duration: 350 } }));
	const [messageSprings, messageApi] = useSpring(()=>({ from: { scale: 0, }, config: { duration: 200 } }));

	useEffect(()=>{
		avatarApi.start({to: { scale: 1, rotate: -360 }})
		messageApi.start({to: { scale: 1 }, delay: 300})
		// eslint-disable-next-line react-hooks/exhaustive-deps
	}, []);

	return (
		<>
			<animated.p style={{...avatarSprings}} className="flex items-center justify-center w-11 h-11 rounded-full text-2xl font-bold bg-red-500 text-white/95">{letter}</animated.p>
			<animated.p style={{...messageSprings}} className="bg-white text-slate-900 p-6 text-sm rounded-2xl rounded-bl-none mb-4 origin-[0%_100%]">{message}</animated.p>
		</>
	)
}

function Details({is_current, header}: {is_current: boolean, header: string}){
	return (
		<div className="my-8">
			<h2 className={`font-bold transition-all duration-200 border-s-[4.5px] border-slate-900 ps-3 text-xl ${is_current ? '!text-3xl' : 'opacity-60 border-opacity-60 uppercase'}`}>{header}</h2>
				<div className={`h-auto overflow-hidden transition-all duration-300 origin-top ${is_current ? 'scale-y-1' : 'scale-y-0 max-h-0'}` }>
				<p className="opacity-80 ps-5 pt-2">
					Our unlimited plan starts at $200/month. Pick a bag size, then
					place 1+ bags for pickup up to 3 times per week. We&apos;ll wash,
					dry, fold/hang and deliver your laundry back to you. Save
					money, ditch per-pound costs and reclaim your valuable time
					with our unlimited weekly service. More time to do what you
					love!
					<br/><br/>Or choose our <b>“Pay-per-Use”</b> option at <b>$2.00/ lb.</b>
				</p>
			</div>
		</div>
	)
}

function Desktop(){
	const [ref, inView] = useInView({ amount: 1 });
	const id = useId();
	const [accordion, setAccordion] = useState<'accordion1'|'accordion2'|'accordion3'>('accordion1');

	function scrollEvent(){
		const container = document.getElementById(id) as HTMLDivElement;
		const { top } = container.getBoundingClientRect();
		if (top < -500) setAccordion("accordion3");
		else if (top < -200) setAccordion("accordion2");
		else if (top < 0) setAccordion("accordion1");
	}

	useEffect(()=>{
		window.addEventListener('scroll', scrollEvent);
		return ()=>{
			window.removeEventListener('scroll', scrollEvent);
		}
		// eslint-disable-next-line react-hooks/exhaustive-deps
	}, []);

	return (
		<div className="h-[1800px] relative" id={id}>
			<section className="p-6 bg-white sticky top-1/2 -translate-y-1/2">
				<p className="text-center text-slate-900 text-4xl sm:text-5xl font-bold leading-10 sticky">Say Goodbye to Laundry Day!</p>
				<p className="text-center text-slate-900 hidden sm:block text-base mt-5">Choose our convenient laundry subscription or pay-as-you-go options.</p>
				<div className="grid grid-cols-1 md:grid-cols-2 gap-x-8 max-w-5xl mx-auto items-center mt-6">
					<div className="relative w-full h-[24rem]">
						{[1, 2, 3].map((n, k)=> <img key={k} srcSet={[640, 1366, 1920].map(v=>(`https://ik.imagekit.io/choreless/v2/images/home/accordion${n}?tr=w-${v} ${v}w`)).join()} alt='accordion image' className={`h-full w-full object-cover rounded-3xl shadow-blue-600/10 shadow-[-7.53px_8.53px_0px] ${ accordion==='accordion'+n ? '' : 'hidden' } ${accordion==='accordion3' && 'object-[center_26%]'}`} />)}
						<div ref={ref} className="absolute bottom-8 start-8">
							<div className="grid grid-cols-[auto_1fr] items-end gap-x-2 me-6 visible">
								{(accordion==='accordion1' && inView) && <DesktopPopup letter='A' message='We know you need to put your oxygen mask on first if you’re going to be truly present for your family, so we make sure to attend to the' />}
								{(accordion==='accordion2' && inView) && <DesktopPopup letter='A' message='We know you need to put your oxygen mask on first if you’re going to be truly present for your family,' />}
								{(accordion==='accordion3' && inView) && <DesktopPopup letter='A' message='We know you need to put your oxygen mask on first if you’re going' />}
							</div>
						</div>
					</div>
					<div>
						<Details is_current={accordion==='accordion1'} header='Unlimited Laundry Plan' />
						<Details is_current={accordion==='accordion2'} header='Personalized Service' />
						<Details is_current={accordion==='accordion3'} header='Flexible Service' />
					</div>
				</div>
			</section>
		</div>
	)
}


function PhonePopup({letter, message}: {letter: string, message: string}){
	const [avatarSprings, avatarApi] = useSpring(()=>({ from: { scale: 0, rotate: 0 }, config: { duration: 350 } }));
	const [messageSprings, messageApi] = useSpring(()=>({ from: { scale: 0 }, config: { duration: 200 } }));
	const [ref, inView] = useInView({ amount: 1 });

	useEffect(()=>{
		if(inView){
			avatarApi.start({to: { scale: 1, rotate: -360 }});
			messageApi.start({to: { scale: 1 }, delay: 300});
		}
		else {
			avatarApi.start({to: { scale: 0, rotate: 0 }});
			messageApi.start({to: { scale: 0 }, delay: 300});
		}
		// eslint-disable-next-line react-hooks/exhaustive-deps
	}, [inView]);

	return (
		<div className='absolute bottom-[1.667rem] start-8'>
			<div className="grid grid-cols-[auto_1fr] items-end gap-x-2 me-6 visible">
				<animated.p ref={ref} style={{...avatarSprings}} className="flex items-center justify-center w-11 h-11 rounded-full text-2xl font-bold bg-red-500 text-white/95">{letter}</animated.p>
				<animated.p style={{...messageSprings}} className="bg-white text-slate-900 p-6 text-sm rounded-2xl rounded-bl-none mb-4 origin-[0%_100%]">{message}</animated.p>
			</div>
		</div>
	)
}

function Phone(){
	const description = (
		<p className="text-justify text-slate-900 leading-tight pb-7">
			Our unlimited plan starts at $200/month. Pick a bag size, then place 1+ bags for pickup up to 3 times per week. We&apos;ll wash, dry, fold/hang, and deliver your laundry back to you.
			<br/><br/>
			Or choose our <b>“Pay-per-Use”</b> option <b>at $2.00/ lb.</b>
		</p>
	)
	const content = [
		{ title: 'Unlimited Laundry Plan', description, popup_message: 'We know you need to put your oxygen mask on first if you’re going to be truly present for your family, so we make sure to attend to the' },
		{ title: 'Personalized Service', description, popup_message: 'We know you need to put your oxygen mask on first if you’re going to be truly present for your family,' },
		{ title: 'Flexible Service', description, popup_message: 'We know you need to put your oxygen mask on first if you’re going to be truly present for your family,' }
	]
	return (
		<div className="mt-[50px] [@media(min-height:800px)_and_(max-width:992px)]:relative">
			<p className="text-center text-slate-900 text-4xl sm:text-5xl font-bold leading-10 mb-5 [@media(min-height:800px)_and_(max-width:992px)]:sticky [@media(min-height:800px)_and_(max-width:992px)]:top-8">Say Goodbye to Laundry Day!</p>
			{
				content.map((v, k)=>{
					return <section key={k} className='bg-white [@media(min-height:800px)_and_(max-width:992px)]:sticky [@media(min-height:800px)_and_(max-width:992px)]:top-[8.5rem]'>
						<div className="relative">
							<img srcSet={[640, 1366, 1920].map(v=>(`https://ik.imagekit.io/choreless/v2/images/home/accordion${k+1}?tr=w-${v} ${v}w`)).join()} alt='accordion image' className='w-full h-[26.667rem] object-cover transition-all duration-300' />
							<PhonePopup letter='A' message={v.popup_message} />
						</div>
						<div className="mt-4 px-4">
							<h3 className="text-center text-slate-900 text-2xl font-bold leading-9"> {v.title}</h3>
							{v.description}
						</div>
					</section>
				})
			}
		</div>
	)
}


export default function SayGoodbyeToLaundryDay(){
	const [screen_width, setScreenWidth] = useState(0);

	useEffect(() => {
		setScreenWidth(window.innerWidth);
		window.onresize = () => { setScreenWidth(window.innerWidth) }
	}, []);

	return <>
		{
			(screen_width > 0 && screen_width < 992) ? <div className="mt-[30px] mb-16"><Phone /></div> :
			((screen_width > 0) && <div className="pt-56 -mb-60"><Desktop /></div>)
		}
	</>
}
